#!/bin/bash
###
#By Daniel Zachrisson
#This is a simple shellscript to control/get some info from amaroK using the dcop interface
#I wrote this script to work with irssi, so I have commented out the calls to 
#the usage function, cus that would be very disturbing if it spamed it into a irc-channel :)
###
#to make it use with irssi do:
# /alias exec -o - </path/to/this/script>
###

ER_ARGS=60
ER_WRONG_ARGS=65
ER_NOT_PLAYING=70
ER_NOT_STARTED=80
IS_PLAYING=75
TWOARGS=2
WHAT_TO_DO=$1
VOL=$2
BASENAME=$(basename $0)

function usage() {
echo "--- $BASENAME ---"
echo 'This is a simple script to control/get info from amaroK
Valid argumets are: 
play, stop, next, prev, info, osd, vol+, vol-, vol, mute, pause, equalizer
Only vol takes two arguments	ex. amarokctl vol 50 (0-100)'
}

function do_control() {
	playing=$(dcop amarok player isPlaying)
	plays=$(dcop amarok player nowPlaying)
	time=$(dcop amarok player totalTime)
	bitrate=$(dcop amarok player bitrate)
	case "$WHAT_TO_DO" in
		"play"	)	
				if [ $playing = "false" ]; then
					#make amaroK play the song makred in playlist
					dcop amarok player play
				else
					#echo "amaroK is already playing: $plays"
					exit $IS_PLAYING
				fi
				;;
		"stop"	)	
				#stop amaroK 
				dcop amarok player stop
				;;
		"next"	)	
				#make amaroK go to next song in playlist
				dcop amarok player next
				;;
		"prev"	)	
				#make amaroK go to previous song in playlist
				dcop amarok player prev
				;;
		"info"	)	
				if [ $playing = "false" ]; then
					#tell that amaroK isn't playing anything and exit
					echo "amaroK is not playing anything"
					exit $ER_NOT_PLAYING
				else
					#tell what amaroK is playing
					echo "amaroK plays: $plays($time) @ $bitrate"
				fi
				;;
		"osd"	)	
				#makes the OSD show
				dcop amarok player showOSD
				;;	
		"vol+"	)	
				#turn volume up
				dcop amarok player volumeUp	
				;;
		"vol-"	)	
				#turn volume down
				dcop amarok player volumeDown
				;;
		"vol"	)	
				#check if there is a second argument to "vol", if it is, set the
				#volume, else call the function usage and quit
				if [ -n "$VOL" ]; then
					dcop amarok player setVolume $VOL
				else
					usage
					exit $ER_ARGS
				fi
				;;
		"mute"	)	
				#set the volume to mute :)
				dcop amarok player mute
				;;
		"pause"	)
				#pause the song
				dcop amarok player pause
				;;
		"equalizer" )	
				#shows the equalizer window
				dcop amarok player configEqualizer
				;;
		*	)	
				#uncomment "usage" if you want it to show in the shell
				#but leave it commented if you use it with irssi
				#usage
				exit $ER_WRONG_ARGS
				;;
	esac
}

	if [ $# -lt "1" ]; then
		#uncomment "usage" if you want it to show in the shell
		#but leave it commented if you use it with irssi
		#usage
		exit $ER_ARGS
	else
		if [ $# -gt $TWOARGS ]; then
			#uncomment "usage" if you want it to show in the shell
			#but leave it commented if you use it with irssi
			#usage
			exit $ER_ARGS
		else
			#call the function do_control
			do_control
		fi
	fi